@@ -3,7 +3,7 @@ import os
 import threading
 
 import mlflow
-
+from waveletai._version import get_versions
 from waveletai import constants, envs
 from waveletai.backends.hosted_backend import HostedBackend
 from waveletai.constants import ModelRegisterMode
@@ -26,14 +26,13 @@ ANONYMOUS = constants.ANONYMOUS
 You can pass this value as api_token during init() call, either by an environment variable or passing it directly
 """
 ANONYMOUS_API_TOKEN = constants.ANONYMOUS_API_TOKEN
-from waveletai._version import get_versions
 
 __version__ = get_versions()
 
 _backend = None
 
 
-def init(name=None, pwd=None, backend=None, api_token=None):
+def init(backend=None, api_token=None):
     with __lock:
         global _backend
 
@@ -43,7 +42,7 @@ def init(name=None, pwd=None, backend=None, api_token=None):
             #     backend = OfflineBackend()
 
             # elif backend_name is None:
-            _backend = HostedBackend(name, pwd, api_token)
+            _backend = HostedBackend(api_token)
 
             # else:
             #     raise InvalidBackend(backend_name)
@@ -68,25 +67,25 @@ def close():
         _backend.close()
 
 
-def set_app_id(app_id):
+def set_app(app_id):
     """
     设置app_id
     :param app_id:
     :return:
     """
-    return _get_backend().set_app_id(app_id)
+    return _get_backend().set_app(app_id)
 
 
-def set_model_id(model_id):
+def set_model(model_id):
     """
     设置model_id
     :param model_id:
     :return:
     """
-    return _get_backend().set_app_id(model_id)
+    return _get_backend().set_model(model_id)
 
 
-def create_app(name, tags=[], desc=None):
+def create_app(name, tags, desc=None):
     """
     创建应用
     :param name :str 应用名称
@@ -97,26 +96,43 @@ def create_app(name, tags=[], desc=None):
     return _get_backend().create_app(name, tags, desc)
 
 
-def get_app(app_id):
+def update_app(name, tags, desc=None):
     """
-    获取应用
-    :param app_id: 应用ID
+    更改应用
+    :param name :str 应用名称
+    :param tags :list 应用标签
+    :param desc :str 应用说明
     :return: App对象
     """
-    return _get_backend().get_app(app_id)
+    return _get_backend().update_app(name, tags, desc)
 
 
-def create_dataset(name, zone, path, data_type=constants.DataType.TYPE_FILE.value, desc=None):
+def delete_app():
+    """
+    删除应用
+    """
+    return _get_backend().delete_app()
+
+
+def get_app():
+    """
+    获取应用
+    :return: App对象
+    """
+    return _get_backend().get_app()
+
+
+def create_dataset(name, path, data_type=constants.DataType.TYPE_FILE.value, visibility='private', desc=None):
     """
     创建数据集
     :param name: 数据集名称
-    :param zone: 数据集区域
     :param path: 要上传的本地数据的路径
     :param data_type: 一个数据集中的数据类型是唯一的。备选值constants.DataType，固定提供图片、文件、视频、视频帧的数据类型
+    :param visibility: 可见性，默认为私有
     :param desc: 数据集详情
     :return: Dataset对象
     """
-    return _get_backend().create_dataset(name, zone, path, data_type, desc)
+    return _get_backend().create_dataset(name, path, data_type, visibility, desc)
 
 
 def get_dataset(dataset_id):
@@ -139,7 +155,7 @@ def download_dataset_artifact(dataset_id, path, destination):
     return _get_backend().download_dataset_artifact(dataset_id, path, destination)
 
 
-def download_dataset_artifacts(data_id, destination, unzip=False, imgtype=None):
+def download_dataset_artifacts(data_id, destination, unzip=False, feature_type=None):
     """
     下载数据集/特征库全部文件到本地指定目录
     :param data_id:数据集ID/特征库ID
@@ -148,7 +164,7 @@ def download_dataset_artifacts(data_id, destination, unzip=False, imgtype=None):
     :param imgtype: 特征库图片类型 pascal_voc/coco
     :return:
     """
-    return _get_backend().download_dataset_artifacts(data_id, destination, unzip, imgtype)
+    return _get_backend().download_dataset_artifacts(data_id, destination, unzip, feature_type)
 
 
 def upload_dataset_artifacts(dataset_id, path):
@@ -161,7 +177,7 @@ def upload_dataset_artifacts(dataset_id, path):
     return _get_backend().upload_dataset_artifacts(dataset_id, path)
 
 
-def create_model(name, app_id, desc=None, auth_id=None, git_url=None, http_url=None):
+def create_model(name, desc=None, auth_id=None, git_url=None, http_url=None):
     """
     创建模型
     :param http_url: http地址 默认空
@@ -169,41 +185,37 @@ def create_model(name, app_id, desc=None, auth_id=None, git_url=None, http_url=N
     :param auth_id: auth_id 默认空
     :param name:模型名称
     :param desc:模型备注 默认空
-    :param app_id:所属应用ID
     :return:
     """
-    return _get_backend().create_model(name, app_id, desc, auth_id, git_url, http_url)
+    return _get_backend().create_model(name, desc, auth_id, git_url, http_url)
 
 
-def get_model(model_id):
+def get_model():
     """
     获取模型对象
-    :param model_id:模型ID
     :return:
     """
-    return _get_backend().get_model(model_id)
+    return _get_backend().get_model()
 
 
-def register_model_version(model_id, desc, artifacts, mode=ModelRegisterMode.PYFUNC.value):
+def register_model_version(desc, artifacts, mode=ModelRegisterMode.PYFUNC.value):
     """
     注册模型库版本
-    :param model_id: 模型ID
     :param desc: 备注
     :param artifacts: 注册文件路径，可以是文件夹,当为docker模式时，此处为docker-image,可以用save命令导出  eg：deployment.tar
     :param mode: 注册模式,默认为自定义(ModelRegisterMode.PYFUNC.value)
     :return:
     """
-    return _get_backend().register_model_version(model_id, desc, artifacts, mode)
+    return _get_backend().register_model_version(desc, artifacts, mode)
 
 
-def get_model_version_by_model(model_id, version):
+def get_model_version_by_model(version):
     """
     过模型获取模型库指定信息
-    :param model_id: 模型ID
     :param version:模型版本号
     :return:
     """
-    return _get_backend().get_model_version(model_id, version)
+    return _get_backend().get_model_version(version)
 
 
 def get_model_version_by_id(model_version_id):
@@ -215,13 +227,12 @@ def get_model_version_by_id(model_version_id):
     return _get_backend().get_repo_by_repo_id(model_version_id)
 
 
-def list_models(app_id):
+def list_models():
     """
     获取模型对象
-    :param app_id:模型ID
     :return:
     """
-    return _get_backend().list_models(app_id)
+    return _get_backend().list_models()
 
 
 def update_dataset(dataset_id, name, zone, desc=None):
@@ -245,64 +256,58 @@ def delete_dataset(dataset_id):
     return _get_backend().delete_dataset(dataset_id)
 
 
-def update_model(model_id, app_id, name, desc=None):
+def update_model(name, visibility, desc=None):
     """
     更新模型集
-    :param model_id:
-    :param app_id:
     :param name:
     :param desc:
+    :param visibilty:
     :return:
     """
-    return _get_backend().update_model(model_id, app_id, name, desc)
+    return _get_backend().update_model(name, visibility, desc)
 
 
-def delete_model(model_id):
+def delete_model():
     """
     删除模型
-    :param model_id:
     :return:
     """
-    return _get_backend().delete_model(model_id)
+    return _get_backend().delete_model()
 
 
-def list_model_versions(model_id):
+def list_model_versions():
     """
     获取注册的各版本模型信息列表
-    :param model_id:
     :return:
     """
-    return _get_backend().list_model_versions(model_id)
+    return _get_backend().list_model_versions()
 
 
-def abandon_model_version(model_id, version):
+def abandon_model_version(version):
     """
     根据模型id，删除指定version
-    :param model_id:
     :param version:
     :return:
     """
-    return _get_backend().abandon_model_version(model_id, version)
+    return _get_backend().abandon_model_version(version)
 
 
-def update_model_version(model_id, version, desc=None):
+def update_model_version(version, desc=None):
     """
     根据模型id，修改指定模型版本
     :param desc:
-    :param model_id:
     :param version:
     :return:
     """
-    return _get_backend().update_model_version(model_id, version, desc)
+    return _get_backend().update_model_version(version, desc)
 
 
-def list_experiments(model_id):
+def list_experiments():
     """
     根据模型id，获取实验数据
-    :param model_id:
     :return:
     """
-    return _get_backend().list_experiments(model_id)
+    return _get_backend().list_experiments()
 
 
 def download_model_version_asset(repo_id, path, destination):
@@ -326,14 +331,13 @@ def download_model_version_artifacts(repo_id, destination):
     return _get_backend().download_model_version_artifacts(repo_id, destination)
 
 
-def list_model_releases(model_id, version):
+def list_model_releases(version):
     """
     根据模型id，版本，获取发布数据
-    :param model_id:
     :param version: 默认为None
     :return:
     """
-    return _get_backend().list_model_releases(model_id, version)
+    return _get_backend().list_model_releases(version)
 
 
 def list_model_releases_by_repo(repo_id):
@@ -345,16 +349,15 @@ def list_model_releases_by_repo(repo_id):
     return _get_backend().list_model_releases_by_repo(repo_id)
 
 
-def create_experiment(name, model_id, desc=None, ):
+def create_experiment(name, desc=None):
     """
     创建实验
     :param name:模型名称
     :param desc:模型备注
-    :param model_id:所属模型ID
     :param params: 参数字典{key:value, ...}
     :return:
     """
-    return _get_backend().create_experiment(name=name, model_id=model_id, params=None, host_id=None,
+    return _get_backend().create_experiment(name=name, params=None, host_id=None,
                                             dataset_id=None, feature_id=None, is_train=True, desc=desc,
                                             mlexp_id=None, artifact_location=None, online_train=False,
                                             docker_args={})
