@@ -9,8 +9,12 @@
 @Desc    : 
 """
 
-VERSION = "0.2.16"
+VERSION = "0.2.18"
 
 
 def get_versions():
     return VERSION
+
+
+if __name__ == '__main__':
+    print(get_versions())
