@@ -18,6 +18,13 @@ ANONYMOUS_API_TOKEN = 'eyJhcGlfYWRkcmVzcyI6Imh0dHBzOi8vdWkubmVwdHVuZS5haSIsImFwa
                       'kiLCJhcGlfa2V5IjoiYjcwNmJjOGYtNzZmOS00YzJlLTkzOWQtNGJhMDM2ZjkzMmU0In0='
 
 
+@unique
+class Visibility(Enum):
+    # 可见性
+    PUBLIC = 'public'  # 公开
+    PRIVATE = 'private'  # 私有
+
+
 @unique
 class ModelRegisterMode(Enum):
     # 注册模型类型
@@ -26,6 +33,12 @@ class ModelRegisterMode(Enum):
     PYFUNC = 'py-func'  # 自定义模型注册
 
 
+@unique
+class FeatureType(Enum):
+    COCO = "coco"
+    FILE = "zip"
+    VOC = "pascal_voc"
+
 @unique
 class DataType(Enum):
     # 文件类型 当前指csv
