@@ -16,31 +16,28 @@ _logger = logging.getLogger(__name__)
 
 class Dataset(object):
 
-    def __init__(self, backend, id, name, desc, zone, dimension, json_data, create_time, data_type, create_user_id,
-                 update_time,
-                 update_user_id):
+    def __init__(self, backend, id, name, visibility, desc, create_time, data_type, create_user_id,
+                 update_time, update_user_id):
         self._backend = backend
         self.id = id
         self.name = name
         self.desc = desc
-        self.zone = zone
-        self.dimension = dimension
-        self.json_data = json_data
+        self.visibility = visibility
         self.create_time = create_time
         self.data_type = data_type
         self.create_user_id = create_user_id
         self.update_time = update_time
         self.update_user_id = update_user_id
 
-    def update(self, name, zone, desc):
+    def update(self, name, visibility=None, desc=None):
         """
         更新当前数据集信息
         :param: name 数据集名称
-        :param: zone 数据集区域
+        :param: visibility 可见性类型
         :param: desc 数据集参数
         :return: Class of `Dataset` Object
         """
-        return self._backend.update_dataset(self.id, name, zone, desc)
+        return self._backend.update_dataset(self.id, name, visibility, desc)
 
     def delete(self):
         """
